@@ -73,31 +73,35 @@ class TikTokApi:
     # Gets trending Tiktoks
     #
 
-    def trending(self, count=30, language='en', proxy=None):
+    def trending(self, count=30, language='en', region='US', proxy=None):
         response = []
         maxCount = 99
         maxCursor = 0
+        first = True
 
         while len(response) < count:
             if count < maxCount:
                 realCount = count
             else:
                 realCount = maxCount
-            api_url = "https://m.tiktok.com/api/item_list/?count={}&id=1&type=5&secUid=&maxCursor={}&minCursor=0&sourceType=12&appId=1233&region=US&language={}&verifyFp=".format(
-                str(realCount), str(maxCursor), str(language))
+            api_url = "https://m.tiktok.com/api/item_list/?count={}&id=1&type=5&secUid=&maxCursor={}&minCursor=0&sourceType=12&appId=1233&region={}&language={}&verifyFp=".format(
+                str(realCount), str(maxCursor), str(region), str(language))
             b = browser(api_url, language=language, proxy=proxy)
             res = self.getData(api_url, b, proxy=proxy)
 
-            for t in res['items']:
-                response.append(t)
+            if 'items' in res.keys():
+                for t in res['items']:
+                    response.append(t)
 
-            if not res['hasMore']:
+            if not res['hasMore'] and not first:
                 print("TikTok isn't sending more TikToks beyond this point.")
                 return response
 
             realCount = count-len(response)
             maxCursor = res['maxCursor']
 
+            first = False
+
         return response[:count]
 
     #
@@ -108,6 +112,7 @@ class TikTokApi:
         response = []
         maxCount = 99
         maxCursor = 0
+        first = True
 
         while len(response) < count:
             if count < maxCount:
@@ -119,16 +124,19 @@ class TikTokApi:
             b = browser(api_url, proxy=proxy)
             res = self.getData(api_url, b, proxy=proxy)
 
-            for t in res['items']:
-                response.append(t)
+            if 'items' in res.keys():
+                for t in res['items']:
+                    response.append(t)
 
-            if not res['hasMore']:
+            if not res['hasMore'] and not first:
                 print("TikTok isn't sending more TikToks beyond this point.")
                 return response
 
             realCount = count-len(response)
             maxCursor = res['maxCursor']
 
+            first = False
+
         return response[:count]
 
     #
@@ -146,6 +154,7 @@ class TikTokApi:
         response = []
         maxCount = 99
         maxCursor = 0
+        first = True
 
         while len(response) < count:
             if count < maxCount:
@@ -165,16 +174,19 @@ class TikTokApi:
                     print("Most Likely User's List is Empty")
                 return []
 
-            for t in res['items']:
-                response.append(t)
+            if 'items' in res.keys():
+                for t in res['items']:
+                    response.append(t)
 
-            if not res['hasMore']:
+            if not res['hasMore'] and not first:
                 print("TikTok isn't sending more TikToks beyond this point.")
                 return response
 
             realCount = count-len(response)
             maxCursor = res['maxCursor']
 
+            first = False
+
         return response[:count]
 
     #
@@ -475,49 +487,24 @@ class TikTokApi:
     #
     # No Water Mark
     #
-    # TikTok Deprecated it see https://github.com/TufayelLUS/TikTok-Video-Downloader-PHP/issues/4
-    #
-    def get_Video_No_Watermark(self, video_url, return_bytes=1, proxy=None):
-        r = requests.get(video_url, headers={"method": "GET",
-                                             "accept-encoding": "utf-8",
-                                             "user-agent": self.userAgent
-                                             }, proxies=self.__format_proxy(proxy))
+    def get_Video_No_Watermark_ID(self, video_id, proxy=None):
+        video_info = self.getTikTokById(video_id)
+        video_url = video_info["itemInfo"]["itemStruct"]["video"]["downloadAddr"]
+        headers = {"User-Agent": "okhttp"}
+        video_data = requests.get(video_url, params=None, headers=headers).text
+        pos = video_data.find("vid:")
+        video_url_no_wm = "https://api2-16-h2.musical.ly/aweme/v1/play/?video_id={" \
+                          "}&vr_type=0&is_play_url=1&source=PackSourceEnum_PUBLISH&media_type=4" \
+            .format(video_data[pos+4:pos+36])
 
-        data = r.text.split("\"contentUrl\":\"")
-        if len(data) > 1:
-            contentURL = data[1].split("\"")[0]
+        headers = {"User-Agent": "okhttp"}
+        video_data_no_wm = requests.get(video_url_no_wm, params=None, headers=headers)
+        return video_data_no_wm.content
 
-            r = requests.get(contentURL, headers={"method": "GET",
-                                                  "accept-encoding": "gzip, deflate, br",
-                                                  'accept-Language': 'en-US,en;q=0.9',
-                                                  'Range': 'bytes=0-200000',
-                                                  'Accept': 'text/html,application/xhtml+xml,application/xml;q=0.9,image/webp,image/apng,*/*;q=0.8,application/signed-exchange;v=b3;q=0.9',
-                                                  "user-agent": self.userAgent
-                                                  }, proxies=self.__format_proxy(proxy))
 
-            tmp = r.text.split("vid:")
-            if len(tmp) > 1:
-                key = tmp[1].split("%")[0]
-
-                if key[-1:] == ' ':
-                    key = key[1:]
-
-                if key[:1] == ' ':
-                    key = key[:-1]
-
-            else:
-                key = ""
-
-            cleanVideo = "https://api2.musical.ly/aweme/v1/playwm/?video_id=" + key
-
-            b = browser(cleanVideo, find_redirect=True, proxy=proxy)
-
-            if return_bytes == 0:
-                return b.redirect_url
-            else:
-                r = requests.get(
-                    b.redirect_url, proxies=self.__format_proxy(proxy))
-                return r.content
+    def get_Video_No_Watermark(self, video_url, proxy=None):
+        video_id = video_url.split("/video/")[1].split("?")[0]
+        return self.get_Video_No_Watermark_ID(video_id, proxy=proxy)
 
     #
     # PRIVATE METHODS
